@@ -12,6 +12,7 @@ OC.L10N.register(
     "Tags" : "Etiquetes",
     "Description" : "Descripció",
     "Settings" : "Paràmetres",
-    "Error" : "Error"
+    "Error" : "Error",
+    "Save" : "Desa"
 },
 "nplurals=2; plural=(n != 1);");
