@@ -3,26 +3,35 @@ OC.L10N.register(
     {
     "Bookmarks" : "Zakładki",
     "Add a Bookmark" : "Dodaj Zakładkę",
+    "Add folder" : "Dodaj folder",
     "Select" : "Wybierz",
     "Deselect" : "Odznacz",
     "Details" : "Szczegóły",
     "Delete" : "Usuń",
     "Saved" : "Zapisano",
+    "Date added" : "Dodano datę",
+    "Link" : "Link",
     "Tags" : "Tagi",
     "Description" : "Opis",
     "No bookmarks here." : "Brak tutaj zakładek.",
+    "Favorites" : "Ulubione",
     "Settings" : "Ustawienia",
     "Bookmarklet" : "Skryptozakładka",
     "Add to {instanceName} " : "Dodaj do {instanceName} ",
     "Recently added" : "Ostatnio dodane",
     "Most visited" : "Najczęściej odwiedzane",
+    "View mode" : "Tryb podglądu",
+    "List view" : "Widok listy",
     "RSS Feed" : "Kanał RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Trwale usuń wszystkie zakładki ze swojego konta. Operacja nieodwracalna!",
     "Delete all bookmarks" : "Usuń wszystkie zakładki",
     "Open details" : "Otwórz szczegóły",
     "An error occurred while trying to save the bookmark." : "Wystąpił błąd podczas próby zapisania zakładki.",
     "Error" : "Błąd",
+    "Uncategorized" : "Bez kategorii",
+    "Error parsing the import result" : "Błąd podczas analizowania wyniku importu",
     "Import completed successfully." : "Importowanie zakończone pomyślnie.",
+    "Do you really want to delete all your bookmarks?" : "Czy na pewno chcesz usunąć wszystkie swoje zakładki?",
     "Set tags" : "Ustaw tagi",
     "Failed to import one bookmark, because: " : "Nie można było zaimportować jednej zakładki ponieważ:",
     "No file provided for import" : "Brak pliku do importu",
