@@ -2,9 +2,6 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Закладки",
-    "Failed to import one bookmark, because: " : "Не удалось импортировать одну закладку, потому, что:",
-    "No file provided for import" : "Не указан файл для импорта",
-    "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
     "Add a Bookmark" : "Добавить закладку",
     "Add folder" : "Добавить каталог",
     "Select" : "Пометить",
@@ -12,6 +9,8 @@ OC.L10N.register(
     "Details" : "Подробно",
     "Delete" : "Удалить",
     "Saved" : "Сохранено",
+    "Date added" : "Дата добавления",
+    "Link" : "Ссылка",
     "Tags" : "Метки",
     "Description" : "Описание",
     "No bookmarks here." : "Нет закладок",
@@ -21,6 +20,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Добавить в {instanceName} ",
     "Recently added" : "Недавно добавленные",
     "Most visited" : "Самый посещаемые",
+    "View mode" : "Режим просмотра",
+    "List view" : "Вид списком",
     "RSS Feed" : "RSS-лента",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Окончательное удаление всех закладок без возможности восстановления.",
     "Delete all bookmarks" : "Удалить все закладки",
@@ -29,7 +30,11 @@ OC.L10N.register(
     "Error" : "Ошибка",
     "Uncategorized" : "Без категории",
     "Import completed successfully." : "Успешное завершение импорта.",
+    "Do you really want to delete all your bookmarks?" : "Вы действительно хотите удалить все ваши закладки?",
     "Set tags" : "Задать метки",
+    "Failed to import one bookmark, because: " : "Не удалось импортировать одну закладку, потому, что:",
+    "No file provided for import" : "Не указан файл для импорта",
+    "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
     "A Bookmark manager for Nextcloud" : "Менеджер закладок для Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Это приложение позволяет хранить и упорядочивать ваши любимые места в Интернете в одном месте, позволяя вам синхронизировать их с различными устройствами и браузерами. Проверьте сторонние клиенты, перечисленные здесь:  https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Добавить закладку",
