@@ -2,9 +2,6 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Záložky",
-    "Failed to import one bookmark, because: " : "Nepodarilo sa importovať jednu záložku, pretože:",
-    "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
-    "Unsupported file type for import" : "Nepodporovaný typ súboru na import",
     "Add a Bookmark" : "Pridať záložku",
     "Add folder" : "Pridať priečinok",
     "Select" : "Označiť",
@@ -12,6 +9,8 @@ OC.L10N.register(
     "Details" : "Detaily",
     "Delete" : "Zmazať",
     "Saved" : "Uložené",
+    "Date added" : "Dátum pridania",
+    "Link" : "Odkaz",
     "Tags" : "Štítky",
     "Description" : "Popis",
     "No bookmarks here." : "Nie sú tu žiadne záložky.",
@@ -21,6 +20,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Pridať do {instanceName}",
     "Recently added" : "Nedávno pridané",
     "Most visited" : "Najnavštevovanejšie",
+    "View mode" : "Režim zobrazenia",
+    "List view" : "Zobraziť ako zoznam",
     "RSS Feed" : "RSS kanál",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Odstrániť všetky záložky z Vášho účtu natrvalo.  Operácia sa nedá vrátiť späť!",
     "Delete all bookmarks" : "Vymazať všetky záložky",
@@ -28,8 +29,13 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Pri pokuse o uloženie záložky sa vyskytla chyba.",
     "Error" : "Chyba",
     "Uncategorized" : "Nezaradené",
+    "Error parsing the import result" : "Chyba pri analýze výsledku importu",
     "Import completed successfully." : "Import úspešne dokončený.",
+    "Do you really want to delete all your bookmarks?" : "Naozaj chcete zmazať všetky svoje zložky?",
     "Set tags" : "Nastaviť štítky",
+    "Failed to import one bookmark, because: " : "Nepodarilo sa importovať jednu záložku, pretože:",
+    "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
+    "Unsupported file type for import" : "Nepodporovaný typ súboru na import",
     "A Bookmark manager for Nextcloud" : "Manažér záložiek pre Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Táto aplikácia umožňuje ukladať a organizovať obľúbené miesta na webe na jednom mieste a zároveň synchronizovať ich s Vašimi ďalšími zariadeniami a prehliadačmi.\nPozrite si aj zoznam ďalších klientov tu: https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Pridať záložku",
